;; Generated package description from taxy.el  -*- no-byte-compile: t -*-
(define-package "taxy" "0.10pre0.20220715.163158" "Programmable taxonomical grouping for arbitrary objects" '((emacs "26.3")) :commit "67d262164aa4068df2a527d5ec3f6d0beb86021d" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("lisp") :url "https://github.com/alphapapa/taxy.el")
